# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of striim.
#
# Scribe is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""
This module exposes functions that store the stations and playlist
information in a database.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

def open_stations_database(flag="c"):
	"""
	Open the stations database.

	@return: A database object representing the stations database.
	@rtype: A database Shelve object.
	"""
	from Striim.Global import metadata_folder
	from os import path
	if not path.exists(metadata_folder):
		from os import makedirs
		makedirs(metadata_folder)
	database_file = path.join(metadata_folder, "stations.gdb")
	from shelve import open
	from anydbm import error
	try:
		database = open(database_file, flag=flag, writeback=False)
	except error:
		database = open(database_file, flag="n", writeback=False)
	return database

def open_playlist_database(flag="c"):
	"""
	Open the playlist database.

	@return: A database object representing the playlist database.
	@rtype: A database Shelve object.
	"""
	from Striim.Global import metadata_folder
	from os import path
	if not path.exists(metadata_folder):
		from os import makedirs
		makedirs(metadata_folder)
	database_file = path.join(metadata_folder, "playlist.gdb")
	from shelve import open
	from anydbm import error
	try:
		database = open(database_file, flag=flag, writeback=False)
	except error:
		database = open(database_file, flag="n", writeback=False)
	return database

def get_stations_from_database():
	"""
	Get stations for striim

	@return: A dictionary with stations information.
	@rtype: A dictionary object.
	"""
	database = open_stations_database("r")
	try:
		stations = database["stations"]
		database.close()
	except:
		stations = None
		database.close()
	return stations

def get_playlist_from_database():
	"""
	Get playlist for striim

	@return: A dictionary with playlist information.
	@rtype: A dictionary object.
	"""
	database = open_playlist_database("r")
	try:
		playlist = database["playlist"]
		database.close()
	except:
		playlist = None
		database.close()
	return playlist

def update_stations_database(data):
	"""
	Store stations in database.

	A dictionary of the format:

		{"station_name": "user_defined_name", "genre", set([uri1, uri2, uri3, ...])}

	@param data: A dictionary with stations information.
	@type data: A Dictionary object.
	"""
	database = open_stations_database("w")
	database["stations"] = data
	database.close()
	return

def update_playlist_database(data):
	"""
	Store playlist in database.

	A dictionary of the format:

		{"station_name": set([uri1, uri2, uri3, ...])}

	@param data: A dictionary with playlist information.
	@type data: A Dictionary object.
	"""
	database = open_playlist_database("w")
	database["playlist"] = data
	database.close()
	return

# -*- coding: utf-8 -*-
# Copyright © 2005 Lateef Alabi-Oki
#
# This file is part of striim.
#
# Scribe is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# striim is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with striim; if not, write to the Free Software
# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

"""
This module exposes functions that store the window position of striim
in a database.

@author: Lateef Alabi-Oki
@organization: The striim Project
@copyright: Copyright © 2005 Lateef Alabi-Oki
@license: GNU GPLv2 or Later
@contact: mystilleef@gmail.com
"""

def open_position_database(flag="c"):
	"""
	Open the position database.

	@return: A database object representing the position database.
	@rtype: A database Shelve object.
	"""
	from Striim.Global import metadata_folder
	from os import path
	if not path.exists(metadata_folder):
		from os import makedirs
		makedirs(metadata_folder)
	database_file = path.join(metadata_folder, "position.gdb")
	from shelve import open
	from anydbm import error
	try:
		database = open(database_file, flag=flag, writeback=False)
	except error:
		database = open(database_file, flag="n", writeback=False)
	return database

def get_window_position_from_database():
	"""
	Get the window postion of striim

	@return: The xcoordinate and ycoordinate of striim's window.
	@rtype: A Tuple object.
	"""
	database = open_position_database("r")
	try:
		window_position = database["position"]
		database.close()
	except:
		window_position = None
		database.close()
	return window_position

def update_window_position_in_database(data):
	"""
	Store the window position of striim

	A tuple with the following format.

		(xcoordinate, ycoordinate)

	@param data: x and ycoordinate of striim's window.
	@type data: A Tuple object.
	"""
	database = open_position_database("w")
	database["position"] = data
	database.close()
	return

def open_visibility_database(flag="c"):
	"""
	Open the visibility database.

	@return: A database object representing the position database.
	@rtype: A database Shelve object.
	"""
	from Striim.Global import metadata_folder
	from os import path
	if not path.exists(metadata_folder):
		from os import makedirs
		makedirs(metadata_folder)
	database_file = path.join(metadata_folder, "visibility.gdb")
	from shelve import open
	from anydbm import error
	try:
		database = open(database_file, flag=flag, writeback=False)
	except error:
		database = open(database_file, flag="n", writeback=False)
	return database

def get_visibility_from_database():
	"""
	Get the window postion of striim

	@return: The xcoordinate and ycoordinate of striim's window.
	@rtype: A Tuple object.
	"""
	database = open_visibility_database("r")
	try:
		is_visible = database["visibility"]
		database.close()
	except:
		is_visible = True
		database.close()
	return is_visible

def update_visibility_database(data):
	"""
	Store the window position of striim

	A tuple with the following format.

		(xcoordinate, ycoordinate)

	@param data: x and ycoordinate of striim's window.
	@type data: A Tuple object.
	"""
	database = open_visibility_database("w")
	database["visibility"] = data
	database.close()
	return
